@@ -3,7 +3,7 @@ package Types::Algebraic;
 use strict;
 use 5.022;
 use warnings;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Keyword::Declare;
 use Moops;
@@ -45,7 +45,11 @@ sub import {
             my $args = join(", ", @idents);
             my $block = $case->{block};
 
-            $res .= "[ '$tag', $count, sub { my ($args) = \@_; $block; return \$Types::Algebraic::_RETURN_SENTINEL; } ],\n";
+            if ($tag) {
+                $res .= "[ '$tag', $count, sub { my ($args) = \@_; $block; return \$Types::Algebraic::_RETURN_SENTINEL; } ],\n";
+            } else {
+                $res .= "[ sub { $block; return \$Types::Algebraic::_RETURN_SENTINEL; } ],\n";
+            }
         }
         $res .= ");\n";
         $res .= 'if (@types_algebraic_match_result != 1 || $types_algebraic_match_result[0] != $Types::Algebraic::_RETURN_SENTINEL) { return @types_algebraic_match_result };' . "\n";
